Trait diem_fuzzer::FuzzTargetImpl [−][src]
pub trait FuzzTargetImpl: Sync + Send + Debug {
fn description(&self) -> &'static str;
fn generate(
&self,
_idx: usize,
_gen: &mut ValueGenerator
) -> Option<Vec<u8>>;
fn fuzz(&self, data: &[u8]);
fn name(&self) -> &'static str { ... }
}Expand description
Implementation for a particular target of a fuzz operation.
Required methods
fn description(&self) -> &'static str
fn description(&self) -> &'static str
A description for this target.
Generates a new example for this target to store in the corpus. idx is the current index
of the item being generated, starting from 0.
Returns Some(bytes) if a value was generated, or None if no value can be generated.